@@ -84,7 +84,7 @@ def parse_filenames(files: list) -> list:
                 df = dt.fread(file, max_nrows=1)
                 r = str(df[0, 0])
                 t, _ = os.path.split(r)
-                if (df.shape[1] == 1) and ((os.path.isabs(t) and os.path.isfile(r)) or os.path.isfile(os.path.join(folder, t))):
+                if (df.shape[1] == 1) and ((os.path.isabs(t) and os.path.isfile(r)) or os.path.isfile(os.path.join(folder, r))):
                     df = dt.fread(file)
                     for i in range(df.shape[0]):
                         r = str(df[i, 0])
